@@ -1,12 +1,12 @@
 #######################################################################
-# $Id: Dpchrist.pm,v 1.37 2010-11-27 08:05:47 dpchrist Exp $
+# $Id: Dpchrist.pm,v 1.39 2010-12-01 20:15:32 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
 
 package Bundle::Dpchrist;
 
-our $VERSION = sprintf("%d.%03d", q$Revision: 1.37 $ =~ /(\d+)/g);
+our $VERSION = sprintf("%d.%03d", q$Revision: 1.39 $ =~ /(\d+)/g);
 
 1;
 
@@ -21,31 +21,32 @@ Bundle::Dpchrist - David Christensen's Perl modules
 
 =head1 CONTENTS
 
-    Dpchrist::Module			1.026
+    Dpchrist::ExtUtils::MakeMaker	1.011
+    Dpchrist::Test			1.006
 
-    Dpchrist::Is			1.027
-    Dpchrist::LangUtil			1.013
-    Dpchrist::Term			1.013
-    Dpchrist::Timestamp			1.016
+    Dpchrist::Is			1.028
+    Dpchrist::LangUtil			1.014
+    Dpchrist::Term			1.014
 
-    Dpchrist::File::Append		1.031
-    Dpchrist::Tag			1.035
+    Dpchrist::Timestamp			1.018
+    Dpchrist::File::Append		1.032
+    Dpchrist::Tag			1.036
 
-    Dpchrist::Debug			1.044
+    Dpchrist::Debug			1.046
 
-    Dpchrist::CGI			1.046
-    Dpchrist::Cvs::NerfTags		1.010
-    Dpchrist::Directory			1.014
-    Dpchrist::File::Find::Duplicates	1.014
-    Dpchrist::File::LimitPath		1.033
-    Dpchrist::File::Newest		1.028
-    Dpchrist::Scripts			1.012
-    Dpchrist::TriangularNumber		1.020
+    Dpchrist::CGI			1.047
+    Dpchrist::Cvs::NerfTags		1.012
+    Dpchrist::Directory			1.015
+    Dpchrist::File::Find::Duplicates	1.015
+    Dpchrist::File::LimitPath		1.034
+    Dpchrist::File::Newest		1.029
+    Dpchrist::Scripts			1.013
+    Dpchrist::TriangularNumber		1.022
 
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.37 $.
+This documentation describes module revision $Revision: 1.39 $.
 
 
 This is alpha test level software
